Class: Jekyll::Layout

Inherits:
Object
  • Object
show all
Includes:
Convertible
Defined in:
lib/jekyll/layout.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Convertible

#converter, #do_layout, #output_ext, #read_yaml, #to_s, #transform

Constructor Details

#initialize(site, base, name) ⇒ Layout

Initialize a new Layout. site is the Site base is the String path to the name is the String filename of the post file

Returns



16
17
18
19
20
21
22
23
24
25
# File 'lib/jekyll/layout.rb', line 16

def initialize(site, base, name)
  @site = site
  @base = base
  @name = name

  self.data = {}

  self.process(name)
  self.read_yaml(base, name)
end

Instance Attribute Details

#contentObject

Returns the value of attribute content.



8
9
10
# File 'lib/jekyll/layout.rb', line 8

def content
  @content
end

#dataObject

Returns the value of attribute data.



8
9
10
# File 'lib/jekyll/layout.rb', line 8

def data
  @data
end

#extObject

Returns the value of attribute ext.



7
8
9
# File 'lib/jekyll/layout.rb', line 7

def ext
  @ext
end

#siteObject

Returns the value of attribute site.



6
7
8
# File 'lib/jekyll/layout.rb', line 6

def site
  @site
end

Instance Method Details

#process(name) ⇒ Object

Extract information from the layout filename name is the String filename of the layout file

Returns nothing



31
32
33
# File 'lib/jekyll/layout.rb', line 31

def process(name)
  self.ext = File.extname(name)
end